@@ -9,7 +9,6 @@ import java.security.cert.CertificateEncodingException;
 import java.security.cert.CertificateException;
 import java.util.ArrayList;
 import java.util.Enumeration;
-import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Vector;
 
@@ -793,13 +792,10 @@ public final class CryptoManager implements TokenSupplier
         importCertToPerm(X509Certificate cert, String nickname)
         throws TokenException, InvalidNicknameException
     {
-        if (nickname==null) {
+        if (nickname == null) {
             throw new InvalidNicknameException("Nickname must be non-null");
         }
-
-        else {
-            return importCertToPermNative(cert,nickname);
-        }
+        return importCertToPermNative(cert,nickname);
     }
 
     /**
@@ -1054,20 +1050,19 @@ public final class CryptoManager implements TokenSupplier
     /********************************************************************/
 
 
-    public native static int getJSSMajorVersion();
-    public native static int getJSSMinorVersion();
-    public native static int getJSSPatchVersion();
-    private native static boolean getJSSDebug();
+    public static native int getJSSMajorVersion();
+    public static native int getJSSMinorVersion();
+    public static native int getJSSPatchVersion();
 
-    public static final String
-    JAR_JSS_VERSION     = "JSS_VERSION = JSS_" + getJSSMajorVersion() +
-                          "_" + getJSSMinorVersion() +
-                          "_" + getJSSPatchVersion();
+    public static final String getJSSVersion() {
+        return String.format("%d.%d.%d", getJSSMajorVersion(), getJSSMinorVersion(), getJSSPatchVersion());
+    }
+
+    public static native boolean getJSSDebug();
 
     public static final boolean JSS_DEBUG = getJSSDebug();
 
-    // Hashtable is synchronized.
-    private Hashtable<Thread, CryptoToken> perThreadTokenTable = new Hashtable<>();
+    private ThreadLocal<CryptoToken> threadToken = new ThreadLocal<>();
 
     /**
      * Sets the default token for the current thread. This token will
@@ -1084,9 +1079,9 @@ public final class CryptoManager implements TokenSupplier
     @Override
     public void setThreadToken(CryptoToken token) {
         if( token != null ) {
-            perThreadTokenTable.put(Thread.currentThread(), token);
+            threadToken.set(token);
         } else {
-            perThreadTokenTable.remove(Thread.currentThread());
+            threadToken.remove();
         }
     }
 
@@ -1104,8 +1099,7 @@ public final class CryptoManager implements TokenSupplier
      */
     @Override
     public CryptoToken getThreadToken() {
-        CryptoToken tok =
-            perThreadTokenTable.get(Thread.currentThread());
+        CryptoToken tok = threadToken.get();
         if( tok == null ) {
             tok = getInternalKeyStorageToken();
         }
@@ -1169,21 +1163,12 @@ public final class CryptoManager implements TokenSupplier
         }
         // 0 certificate usage will get current usage
         // should call isCertValid() call above that returns certificate usage
-        if ((certificateUsage == null) ||
-                (certificateUsage == CertificateUsage.CheckAllUsages)){
-            int currCertificateUsage = 0x0000;
-            currCertificateUsage = verifyCertificateNowCUNative(nickname,
-                checkSig);
-
-            if (currCertificateUsage == CertificateUsage.basicCertificateUsages){
-                // cert is good for nothing
-                return false;
-            } else
-                return true;
-        } else {
-            return verifyCertificateNowNative(nickname, checkSig,
-              certificateUsage.getUsage());
+        if (certificateUsage == null || certificateUsage == CertificateUsage.CheckAllUsages) {
+            int currCertificateUsage = verifyCertificateNowCUNative(nickname, checkSig);
+            return currCertificateUsage != CertificateUsage.basicCertificateUsages;
         }
+        return verifyCertificateNowNative(nickname, checkSig,
+          certificateUsage.getUsage());
     }
 
     /**
